<?php
/*
Plugin Name: Rows Per Page - in frontend (EasyToolsWP)
Plugin URI: https://www.easytoolswp.com/plugins/rows-pr-page-frontend.zip
Description: Adds a dropdown on frontend archive pages to select the number of rows per page.
Version: 1.0
Author: EasyToolsWP.com
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Hook to add the dropdown on WooCommerce shop pages
add_action('woocommerce_before_shop_loop', 'add_frontend_per_page_dropdown', 20);

// Hook to add the dropdown on regular archive pages and the home page
add_action('wp_head', 'conditionally_add_frontend_per_page_dropdown');

function conditionally_add_frontend_per_page_dropdown() {
    if (!is_shop() && (is_archive() || is_home())) {
        add_action('loop_start', 'add_frontend_per_page_dropdown', 10);
    }
}

function add_frontend_per_page_dropdown() {
    // Ensure we don't add the dropdown multiple times
    static $dropdown_added = false;
    if ($dropdown_added) {
        return;
    }
    $dropdown_added = true;

    $selected = isset($_GET['posts_per_page']) ? intval($_GET['posts_per_page']) : get_option('posts_per_page');
    ?>
    <div class="posts-per-page-dropdown" style="margin-left: 10px; text-align: center; width: 100px; float: right;">
        <form method="GET">
            <select name="posts_per_page" id="posts_per_page" onchange="this.form.submit()">
                <option value="10" <?php selected($selected, 10); ?>>10</option>
                <option value="20" <?php selected($selected, 20); ?>>20</option>
                <option value="50" <?php selected($selected, 50); ?>>50</option>
                <option value="75" <?php selected($selected, 75); ?>>75</option>
                <option value="100" <?php selected($selected, 100); ?>>100</option>
            </select>
        </form>
    </div>
    <?php
}

// Adjust the number of posts per page based on the selected value
add_action('pre_get_posts', 'set_frontend_posts_per_page');

function set_frontend_posts_per_page($query) {
    if ($query->is_main_query() && (is_archive() || is_home() || (function_exists('is_shop') && is_shop())) && isset($_GET['posts_per_page'])) {
        $query->set('posts_per_page', intval($_GET['posts_per_page']));
    }
}
